@@ -39,11 +39,6 @@
 #  define EFIVARFS_MAGIC 0xde5e81e4
 #endif
 
-typedef struct efi_variable_t {
-	uint32_t	Attributes;
-	uint8_t		Data[];
-} __attribute__((packed)) efi_variable_t;
-
 static int
 efivarfs_probe(void)
 {
@@ -83,7 +78,7 @@ efivarfs_get_variable_size(efi_guid_t guid, const char *name, size_t *size)
 	if (rc < 0)
 		goto err;
 
-	struct stat statbuf;
+	struct stat statbuf = { 0, };
 	rc = stat(path, &statbuf);
 	if (rc < 0)
 		goto err;
@@ -150,7 +145,7 @@ efivarfs_get_variable(efi_guid_t guid, const char *name, uint8_t **data,
 
 	*attributes = ret_attributes;
 	*data = ret_data;
-	*data_size = size;
+	*data_size = size - 1; // read_file pads out 1 extra byte to NUL it */
 
 	ret = 0;
 err:
@@ -264,6 +259,7 @@ efivarfs_chmod_variable(efi_guid_t guid, const char *name, mode_t mode)
 }
 
 struct efi_var_operations efivarfs_ops = {
+	.name = "efivarfs",
 	.probe = efivarfs_probe,
 	.set_variable = efivarfs_set_variable,
 	.append_variable = efivarfs_append_variable,
